@@ -12,7 +12,7 @@
 #' @importFrom yaml as.yaml
 #' @export
 Visualize <- function(ahpTree,
-                      criteriaNodesStyle = list(style = "filled,rounded", shape = "box", color = "honeydew4", fillcolor = "honeydew", penwidth = 4, fontname="helvetica"),
+                      criteriaNodesStyle = list(style = "filled,rounded", shape = "box", color = "honeydew4", fillcolor = "honeydew", penwidth = 4, fontname="helvetica", fontcolor = "black"),
                       alternativeNodesStyle = list(style = "filled,rounded", shape = "box", color = "thistle4", fillcolor = "thistle", penwidth = 4, fontname="helvetica"),
                       criteriaEdgesStyle = list(arrowhead = "vee", color = "grey35", penwidth = 2),
                       alternativeEdgesStyle = list(dir = "none", color = "grey35", penwidth = 2)
@@ -82,8 +82,8 @@ GetGraph <- function(ahpTree,
   
   edges <- DiagrammeR::combine_edfs(edges, edgesAlt, edgesAlts)
   
-  graph <- DiagrammeR::create_graph(nodes, edges)
-  graph <- DiagrammeR::set_global_graph_attrs(graph, "rankdir", "TB", "graph")
+  graph <- DiagrammeR::create_graph(nodes, edges, attr_theme = NULL)
+  graph <- DiagrammeR::add_global_graph_attrs(graph, "rankdir", "TB", "graph")
   return (graph)
   
 }
